@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# In[134]:
+# In[286]:
 
 
 try:
@@ -12,10 +12,10 @@ except:
         pass
 
 
-# In[135]:
+# In[285]:
 
 
-version = '0.92'
+version = '0.93'
 
 import re
 import tempfile
@@ -1244,7 +1244,7 @@ if is_testing():
 
 # # Files
 
-# In[233]:
+# In[281]:
 
 
 def _fiFindByWildcardSsh(wildcard):
@@ -1255,7 +1255,14 @@ def _fiFindByWildcardSsh(wildcard):
 def fiFindByWildcard(wildcard):
     if '@' in wildcard and ':' in wildcard:
         return _fiFindByWildcardSsh(wildcard)
-    return natsort.natsorted(glob.glob(wildcard, recursive=True))
+    return natsort.natsorted(glob.glob(os.path.expanduser(wildcard), recursive=True))
+
+def fiFindImgs(dir_path, recursive=False, ext='png'):
+    if recursive:
+        wildcard = os.path.join(dir_path, f'**/*.{ext}')
+    else:
+        wildcard = os.path.join(dir_path, f'*.{ext}')
+    return fiFindByWildcard(wildcard)
 
 
 # In[234]:
@@ -1675,14 +1682,14 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE."""
 
 
-# In[268]:
+# In[272]:
 
 
 if is_testing():
     package_files['README.md'] = ""
 
 
-# In[269]:
+# In[273]:
 
 
 if is_testing():
@@ -1690,7 +1697,7 @@ if is_testing():
     package_files['lx/__init__.py'] = txtread("lx.py")
 
 
-# In[270]:
+# In[274]:
 
 
 if is_testing():
@@ -1701,7 +1708,7 @@ lx/__init__.py
 """
 
 
-# In[271]:
+# In[275]:
 
 
 if is_testing():
